@@ -5,16 +5,17 @@ function(web, count=FALSE){
     # 2. return how many cols and rows had to be removed
     # together with extinction, it counts how many species were affected by the
     # removal of a species, because these rows/cols are now empty
-    # C.FALSE. Dormann, 6 Mar 2007
+    # C.F. Dormann, 6 Mar 2007
 
     web[is.na(web)] <- 0
 
-    if (NCOL(web)==1 & NROW(web)==1)
+    if (NCOL(web)==1 | NROW(web)==1)
     {
-        if (NCOL(web)==1) {nr <- sum(web>0); nc <- 1}
-        if (NROW(web)==1) {nc <- sum(web>0); nr <- 1}
-        out <- 0
-        attr(out, "empty") <- c("empty rows"=nr, "empty columns"=nc)
+        if (NCOL(web)==1 & NROW(web) != 1) {nr <- sum(web>0); nc <- 1}
+        if (NROW(web)==1 & NCOL(web) != 1) {nc <- sum(web>0); nr <- 1}
+	      if (NROW(web)==1 & NCOL(web) == 1) {nr <- 1; nc <- 1}
+        out <- web[1:nr, 1:nc, drop=FALSE]
+        if (count) attr(out, "empty") <- c("empty rows"=NROW(web)-nr, "empty columns"=NCOL(web)-nc)
         return(out)
     }
 
