@@ -49,7 +49,7 @@ nullmodel <- function(web, N=1000, method="r2d", ...){
     }
     
     if (m == 4){ #shuffle.web
-        if (any(web > 1)) out <- shuffle.web(web, N)
+        if (any(web > 1)) out <- shuffle.web(web, N, ...)
         if (all(web < 2)) out <- replicate(n=N, expr=unname(commsimulator(web, method="quasiswap", ...)), simplify=FALSE) 
     }
 
